@@ -23,11 +23,14 @@ def json_util(data):
     """
     if isinstance(data, dict):
         data = json.dumps(data)
-        return '成功转换成json格式'
+        print("成功转换成json格式")
+        return "成功转换成json格式"
     elif isinstance(data, str):
         data = json.loads(data)
-        return '成功转换为dict格式'
+        print("成功转换为dict格式")
+        return "成功转换为dict格式"
     else:
+        print("请输入json或dict数据")
         return"请输入json或dict数据"
 
 
